Android Security Report
For Internal Purpose
Prepared For: com.foo.bar

Prepared by XYSec Labs Pte. Ltd. Portions of this document and the templates used in its production are the property of XYSec Labs Pte. Ltd. and cannot be copied without permission.

While precautions have been taken in the preparation of this document, XYSec Labs Pte. Ltd., the publisher, and the author(s) assume no responsibility for errors, omissions, or for damages resulting from the use of the information contained herein. Use of XYSec Labs Pte. Ltd. services does not guarantee the security of a system, or that intrusions will not occur.

##### Application Details

Application Name | com.foo.bar
Application Namespace | com.foo.bar
Version | 1.0
Audit Date | 2017-03-03 09:17:31.568149+00:00
Application SHA1 Hash | d5341a898eb1d1e90a316d49e8f6b4f33ad08cf0
Application MD5 Hash | 97d83c689f2cb0118e1901054165e8fe

### Table Of Contents

Report Summary
Audit Summary
Appknox Security Rating

### Report Summary

Appknox conducted a security assessment of the mobile application for the Android platform. This report contains all the findings during the automated auditing process. It also contains the process of discovering those vulnerabilities in the first place, and ways to remediate those issues.

##### Audit Summary

Priority Level | Number of failed test cases
High Risk |
Medium Risk |
Low Risk |

##### Appknox Security Rating

Appknox Security Rating: Unsecured